
## CATO-CLI - query.policy.clientConnectivity.policy:
[Click here](https://api.catonetworks.com/documentation/#query-query.policy.clientConnectivity.policy) for documentation on this operation.

### Usage for query.policy.clientConnectivity.policy:

```bash
catocli query policy clientConnectivity policy -h

catocli query policy clientConnectivity policy <json>

catocli query policy clientConnectivity policy --json-file query.policy.clientConnectivity.policy.json

catocli query policy clientConnectivity policy '{"clientConnectivityPolicyInput":{"policyRevisionInput":{"id":"id","type":"PRIVATE"}}}'

catocli query policy clientConnectivity policy '{
    "clientConnectivityPolicyInput": {
        "policyRevisionInput": {
            "id": "id",
            "type": "PRIVATE"
        }
    }
}'
```

#### Operation Arguments for query.policy.clientConnectivity.policy ####

`accountId` [ID] - (required) N/A    
`clientConnectivityPolicyInput` [ClientConnectivityPolicyInput] - (required) N/A    
